//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[UnionShantenResult](index.md)/[regular](regular.md)

# regular

[common]\
val [regular](regular.md): [RegularShantenResult](../-regular-shanten-result/index.md)

标准形向听分析结果
